Changelog
=========

This document describes changes between each past release.

1.0.0 (2016-11-22)
------------------

**Initial version**

- Supports dumping/loading groups and permissions from/to a YAML file.
